/*
 * Copyright 2015 Austin Keener, Michael Ritter, Florian Spieß, and the JDA contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.dv8tion.jda.internal.interactions;

import net.dv8tion.jda.api.exceptions.InteractionFailureException;
import net.dv8tion.jda.api.interactions.InteractionHook;
import net.dv8tion.jda.api.interactions.callbacks.IDeferrableCallback;
import net.dv8tion.jda.api.utils.data.DataObject;
import net.dv8tion.jda.internal.JDAImpl;

import javax.annotation.Nonnull;

public class DeferrableInteractionImpl extends InteractionImpl implements IDeferrableCallback
{
    protected final InteractionHookImpl hook;

    public DeferrableInteractionImpl(JDAImpl jda, DataObject data)
    {
        super(jda, data);
        this.hook = new InteractionHookImpl(this, jda);
    }

    @Override
    public synchronized void releaseHook(boolean success)
    {
        if (success)
            hook.ready();
        else
            hook.fail(new InteractionFailureException());
    }

    @Nonnull
    @Override
    public InteractionHook getHook()
    {
        return hook;
    }
}
